@@ -148,6 +148,12 @@ class RPackage {
    // get origin of the package
    string getCanidateOrigin();
 
+   // get installed component (like main, contrib, non-free)
+   string component();
+   
+   // get label of download site
+   string label();
+   
    const char *maintainer();
    const char *vendor();
 
@@ -247,6 +253,11 @@ class RPackageStatus {
    };
 
  protected:
+   // the supported archive-labels and components
+   vector<string> supportedLabels;
+   vector<string> supportedComponents;
+   bool markUnsupported;
+
    // this is the short string to load the icons
    const char *PackageStatusShortString[N_STATUS_COUNT];
    // this is the long string for the gui description of the state
@@ -258,8 +269,8 @@ class RPackageStatus {
 
 
  public:
-   RPackageStatus() {
-   };
+   RPackageStatus() : markUnsupported(false) {};
+   virtual ~RPackageStatus() {};
 
    // this reads the pixmaps and the colors
    virtual void init();
@@ -275,8 +286,13 @@ class RPackageStatus {
    const char *getShortStatusString(int i) {
       return PackageStatusShortString[i];
    };
+
+   bool isSupported(RPackage *pkg);
+   
 };
 
+
+
 #endif
 
 // vim:ts=3:sw=3:et
