@@ -77,13 +77,14 @@ RPackageLister::RPackageLister()
    _updating = true;
    _sortMode = LIST_SORT_NAME;
 
+   // keep order in sync with rpackageview.h 
    _views.push_back(new RPackageViewSections(_packages));
    _views.push_back(new RPackageViewStatus(_packages));
-   _views.push_back(new RPackageViewAlphabetic(_packages));
    _filterView = new RPackageViewFilter(_packages);
    _views.push_back(_filterView);
    _searchView =  new RPackageViewSearch(_packages);
    _views.push_back(_searchView);   
+   //_views.push_back(new RPackageViewAlphabetic(_packages));
 
    if (_viewMode >= _views.size())
       _viewMode = 0;
@@ -91,6 +92,8 @@ RPackageLister::RPackageLister()
 
    memset(&_searchData, 0, sizeof(_searchData));
 
+   _pkgStatus.init();
+
 #if 0
    string Recommends = _config->Find("Synaptic::RecommendsFile",
                                      "/etc/apt/metadata");
@@ -108,9 +111,12 @@ RPackageLister::~RPackageLister()
    delete _cache;
 }
 
-void RPackageLister::setView(int index)
+void RPackageLister::setView(unsigned int index)
 {
-   _config->Set("Synaptic::ViewMode", index);
+   // only save this config if it is not a search
+   if(index != PACKAGE_VIEW_SEARCH)
+      _config->Set("Synaptic::ViewMode", index);
+
    if(index < _views.size())
       _selectedView = _views[index];
    else
@@ -545,28 +551,33 @@ void RPackageLister::reapplyFilter()
    sortPackages(_sortMode);
 }
 
-
 static const int status_sort_magic = (  RPackage::FInstalled 
 				      | RPackage::FOutdated 
 				      | RPackage::FNew);
-struct statusSortFuncAsc {
+struct statusSortFunc {
    bool operator() (RPackage *x, RPackage *y) {
       return (x->getFlags() & (status_sort_magic))  <
 	     (y->getFlags() & (status_sort_magic));
 }};
-struct statusSortFuncDes {
-   bool operator() (RPackage *x, RPackage *y) {
-      return (x->getFlags() & (status_sort_magic))  > 
-	     (y->getFlags() & (status_sort_magic));
-}};
 
-struct instSizeSortFuncAsc {
+struct instSizeSortFunc {
    bool operator() (RPackage *x, RPackage *y) {
       return x->installedSize() < y->installedSize();
 }};
-struct instSizeSortFuncDes {
+
+struct dlSizeSortFunc {
    bool operator() (RPackage *x, RPackage *y) {
-      return x->installedSize() > y->installedSize();
+      return x->availablePackageSize() < y->availablePackageSize();
+}};
+
+struct componentSortFunc {
+   bool operator() (RPackage *x, RPackage *y) {
+      return x->component() < y->component();
+}};
+
+struct sectionSortFunc {
+   bool operator() (RPackage *x, RPackage *y) {
+      return x->section() < y->section();
 }};
 
 // version string compare
@@ -580,29 +591,36 @@ int verstrcmp(const char *x, const char *y)
       return false;
    return true;
 }
-struct versionSortFuncAsc {
-   bool operator() (RPackage *x, RPackage *y) {
-      return verstrcmp(x->availableVersion(),
-		      y->availableVersion());
-}};
 
-struct versionSortFuncDes {
+struct versionSortFunc {
    bool operator() (RPackage *x, RPackage *y) {
       return verstrcmp(y->availableVersion(),
-		      x->availableVersion());
-}};
-struct instVersionSortFuncAsc {
-   bool operator() (RPackage *x, RPackage *y) {
-      return verstrcmp(x->installedVersion(),
-		      y->installedVersion());
-}};
+		       x->availableVersion());
+   }
+};
 
-struct instVersionSortFuncDes {
+struct instVersionSortFunc {
    bool operator() (RPackage *x, RPackage *y) {
       return verstrcmp(y->installedVersion(),
-		      x->installedVersion());
+		       x->installedVersion());
 }};
 
+struct supportedSortFunc {
+ protected:
+   bool _ascent;
+   RPackageStatus _status;
+ public:
+   supportedSortFunc::supportedSortFunc(bool ascent, RPackageStatus &s) 
+      : _ascent(ascent), _status(s) {};
+   bool operator() (RPackage *x, RPackage *y) {
+      if(_ascent)
+	 return _status.isSupported(y) < _status.isSupported(x);
+      else
+	 return _status.isSupported(y) > _status.isSupported(x);
+   }
+};
+
+
 
 void RPackageLister::sortPackages(vector<RPackage *> &packages, 
 				  listSortMode mode)
@@ -616,31 +634,76 @@ void RPackageLister::sortPackages(vector<RPackage *> &packages,
       qsSortByName(packages, 0, packages.size() - 1);
       break;
    case LIST_SORT_SIZE_ASC:
-      stable_sort(packages.begin(), packages.end(), instSizeSortFuncAsc());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<instSizeSortFunc>(true));
       break;
    case LIST_SORT_SIZE_DES:
-      stable_sort(packages.begin(), packages.end(), instSizeSortFuncDes());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<instSizeSortFunc>(false));
+      break;
+   case LIST_SORT_DLSIZE_ASC:
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<dlSizeSortFunc>(true));
+      break;
+   case LIST_SORT_DLSIZE_DES:
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<dlSizeSortFunc>(false));
+      break;
+   case LIST_SORT_COMPONENT_ASC:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<componentSortFunc>(true));
+      break;
+   case LIST_SORT_COMPONENT_DES:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 		  
+		  sortFunc<componentSortFunc>(false));
+      break;
+   case LIST_SORT_SECTION_ASC:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<sectionSortFunc>(true));
+      break;
+   case LIST_SORT_SECTION_DES:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<sectionSortFunc>(false));
       break;
    case LIST_SORT_STATUS_ASC:
       qsSortByName(packages, 0, packages.size() - 1);
-      stable_sort(packages.begin(), packages.end(), statusSortFuncAsc());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<statusSortFunc>(true));
       break;
    case LIST_SORT_STATUS_DES:
       qsSortByName(packages, 0, packages.size() - 1);
-      stable_sort(packages.begin(), packages.end(), statusSortFuncDes());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<statusSortFunc>(false));
+      break;
+   case LIST_SORT_SUPPORTED_ASC:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 
+		  supportedSortFunc(true, _pkgStatus));
+      break;
+   case LIST_SORT_SUPPORTED_DES:
+      qsSortByName(packages, 0, packages.size() - 1);
+      stable_sort(packages.begin(), packages.end(), 
+		  supportedSortFunc(false, _pkgStatus));
       break;
    case LIST_SORT_VERSION_ASC:
-      stable_sort(packages.begin(), packages.end(), versionSortFuncAsc());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<versionSortFunc>(true));
       break;
    case LIST_SORT_VERSION_DES:
-
-      stable_sort(packages.begin(), packages.end(), versionSortFuncDes());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<versionSortFunc>(false));
       break;
    case LIST_SORT_INST_VERSION_ASC:
-      stable_sort(packages.begin(), packages.end(), instVersionSortFuncAsc());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<instVersionSortFunc>(true));
       break;
    case LIST_SORT_INST_VERSION_DES:
-      stable_sort(packages.begin(), packages.end(), instVersionSortFuncDes());
+      stable_sort(packages.begin(), packages.end(), 
+		  sortFunc<instVersionSortFunc>(false));
       break;
    }
 }
@@ -1279,6 +1342,9 @@ bool RPackageLister::commitChanges(pkgAcquireStatus *status,
          if (Transient)
             goto gave_wood;
 
+	 if (numPackages == 0)
+	     goto gave_wood;
+
          message =
             _("Some of the packages could not be retrieved from the server(s).\n");
          if (!serverError.empty())
