@@ -35,6 +35,8 @@ RGGladeWindow::RGGladeWindow(RGWindow *parent, string name, string mainName)
 {
    //std::cout << "RGGladeWindow::RGGladeWindow(parent,name)" << endl;
 
+   _busyCursor = gdk_cursor_new(GDK_WATCH);
+
    // for development
    gchar *filename = NULL;
    gchar *main_widget = NULL;
@@ -65,7 +67,7 @@ RGGladeWindow::RGGladeWindow(RGWindow *parent, string name, string mainName)
    g_free(filename);
    g_free(main_widget);
 
-   gtk_window_set_title(GTK_WINDOW(_win), (char *)name.c_str());
+   //gtk_window_set_title(GTK_WINDOW(_win), (char *)name.c_str());
 
    gtk_object_set_data(GTK_OBJECT(_win), "me", this);
    gtk_signal_connect(GTK_OBJECT(_win), "delete-event",
@@ -194,3 +196,17 @@ bool RGGladeWindow::setPixmap(const char *widget_name, GdkPixbuf *value)
    
    return true;
 }
+
+void RGGladeWindow::setBusyCursor(bool flag) 
+{
+   if(flag) {
+      gdk_window_set_cursor(window()->window, _busyCursor);
+#if GTK_CHECK_VERSION(2,4,0)
+      // if we don't iterate here, the busy cursor is not shown
+      while (gtk_events_pending())
+	 gtk_main_iteration();
+#endif
+   } else {
+      gdk_window_set_cursor(window()->window, NULL);
+   }
+}
