@@ -65,13 +65,6 @@ typedef enum {
 } RGPkgAction;
 
 class RGMainWindow : public RGGladeWindow, public RPackageObserver {
-   enum {
-      DoNothing,
-      InstallRecommended,
-      InstallSuggested,
-      InstallSelected
-   };
-
    typedef enum {
       UPGRADE_ASK = -1,
       UPGRADE_NORMAL = 0,
@@ -94,7 +87,6 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
    GtkWidget *_treeView;
 
    // the left-side view
-   GtkWidget *_viewPopup;
    GtkWidget *_subViewList;
 
    GtkWidget *_statusL;
@@ -126,9 +118,7 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
 
    GtkWidget *_findText;
    GtkWidget *_findSearchB;
-#if 0
-   GtkWidget *_editFilterB;
-#endif
+
    // package info tabs   
    GtkWidget *_pkginfo;
    GtkWidget *_vpaned;
@@ -155,6 +145,7 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
 
    RGCacheProgress *_cacheProgress;
    RGUserDialog *_userDialog;
+   GtkWidget *_viewButtons[N_PACKAGE_VIEWS];
 
    // init stuff 
    void buildInterface();
@@ -163,11 +154,6 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
  private:
    // display/table releated
    void refreshTable(RPackage *selectedPkg = NULL);
-#if 0
-   void changeFilter(int filter, bool sethistory = true);
-#endif
-
-   GtkWidget *createViewMenu();
    void refreshSubViewList();
 
    virtual bool close();
@@ -176,10 +162,6 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
    };
 
    // misc
-#if 0
-   GtkWidget *createFilterMenu();
-   void refreshFilterMenu();
-#endif
    void forgetNewPackages();
 
    // package info
@@ -206,6 +188,7 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
    // helper for recommends/suggests 
    // (data is the name of the pkg, self needs to have a pointer to "me" )
    static void pkgInstallByNameHelper(GtkWidget *self, void *data);
+   void installAllWeakDepends(RPackage *pkg, pkgCache::Dep::DepType type);
 
    // install a non-standard version (data is a char* of the version)
    static void cbInstallFromVersion(GtkWidget *self, void *data);
@@ -221,7 +204,7 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
    RGMainWindow(RPackageLister *packLister, string name);
    virtual ~RGMainWindow() {};
 
-   void changeView(int view, bool sethistory = true, string subView="");
+   void changeView(int view, string subView="");
 
    // install the list of packagenames and display a changes window
    void selectToInstall(vector<string> packagenames);
@@ -266,7 +249,7 @@ class RGMainWindow : public RGGladeWindow, public RPackageObserver {
                                          GtkTreeViewColumn *arg2,
                                          gpointer user_data);
 
-   static void cbChangedView(GtkWidget *self);
+   static void cbChangedView(GtkWidget *self, void *);
    static void cbChangedSubView(GtkTreeSelection *selection, gpointer data);
 
    static void cbDetailsWindow(GtkWidget *self, void *data);
